# Welcome!

<img src="artwork/toyplot.png" width="300" style="float:right"/>

Welcome to Toyplot, the kid-sized plotting toolkit for Python with grownup-sized goals:

* Develop beautiful interactive, animated plots that embrace the unique capabilities of electronic publishing and support repoducibility.
* Create the best possible data graphics “out-of-the-box”, maximizing data ink and minimizing chartjunk.
* Provide a clean, minimalist interface that scientists and engineers will love.

You can see the full Toyplot documentation with tutorials at
https://toyplot.readthedocs.io ... for questions, comments, or suggestions, get
in touch with our team at https://gitter.im/sandialabs/toyplot.

